Source: xine-lib-1.2
Version: 1.2.13+hg20230710-1
Severity: minor
Tags: trixie sid ftbfs
User: [email protected]
Usertags: ftbfs-sab-20230813 ftbfs-source-after-build
User: [email protected]
Usertags: qa-doublebuild

Hi,

This package fails to build a source package after a successful build
(dpkg-buildpackage ; dpkg-buildpackage -S).

This is probably a clear violation of Debian Policy section 4.9 (clean target),
but this is filed as severity:minor for now, because a discussion on
debian-devel showed that we might want to revisit the requirement of a working
'clean' target.

More information about this class of issues, included common problems and
solutions, is available at
https://wiki.debian.org/qa.debian.org/FTBFS/SourceAfterBuild

Relevant part of the build log:
> cd /<<PKGBUILDDIR>> && runuser -u user42 -- dpkg-buildpackage --sanitize-env 
> -us -uc -rfakeroot -S
> -------------------------------------------------------------------------------------------------------------------------------------------
> 
> dpkg-buildpackage: info: source package xine-lib-1.2
> dpkg-buildpackage: info: source version 1.2.13+hg20230710-1
> dpkg-buildpackage: info: source distribution unstable
> dpkg-buildpackage: info: source changed by Patrick Matthäi 
> <[email protected]>
>  dpkg-source --before-build .
>  debian/rules clean
> dh clean
>    dh_auto_clean
>       make -j8 distclean
> make[1]: Entering directory '/<<PKGBUILDDIR>>'
> Making distclean in doc
> make[2]: Entering directory '/<<PKGBUILDDIR>>/doc'
> Making distclean in man/en
> make[3]: Entering directory '/<<PKGBUILDDIR>>/doc/man/en'
> rm -rf .libs _libs
> rm -f *.lo
> test -z "" || rm -f 
> test . = "." || test -z "" || rm -f 
> test -z "xine-list-1.2.1" || rm -f xine-list-1.2.1
> rm -f Makefile
> make[3]: Leaving directory '/<<PKGBUILDDIR>>/doc/man/en'
> Making distclean in hackersguide
> make[3]: Entering directory '/<<PKGBUILDDIR>>/doc/hackersguide'
> rm -rf .libs _libs
> rm -f *.lo
> test -z "" || rm -f 
> rm -f hackersguide.html architecture.png library.png overlays.png 
> post_frame.png
> test . = "." || test -z "" || rm -f 
> test -z "hackersguide.html architecture.png library.png overlays.png 
> post_frame.png" || rm -f hackersguide.html architecture.png library.png 
> overlays.png post_frame.png
> rm -f Makefile
> make[3]: Leaving directory '/<<PKGBUILDDIR>>/doc/hackersguide'
> Making distclean in faq
> make[3]: Entering directory '/<<PKGBUILDDIR>>/doc/faq'
> rm -rf .libs _libs
> rm -f *.lo
> test -z "" || rm -f 
> rm -f faq.txt faq.html
> test . = "." || test -z "" || rm -f 
> test -z "faq.txt faq.html" || rm -f faq.txt faq.html
> rm -f Makefile
> make[3]: Leaving directory '/<<PKGBUILDDIR>>/doc/faq'
> make[3]: Entering directory '/<<PKGBUILDDIR>>/doc'
> rm -rf .libs _libs
> rm -f *.lo
> test -z "Doxyfile" || rm -f Doxyfile
> rm -f TAGS ID GTAGS GRTAGS GSYMS GPATH tags
> test . = "." || test -z "" || rm -f 
> make[3]: Leaving directory '/<<PKGBUILDDIR>>/doc'
> rm -f Makefile
> make[2]: Leaving directory '/<<PKGBUILDDIR>>/doc'
> Making distclean in po
> make[2]: Entering directory '/<<PKGBUILDDIR>>/po'
> rm -f *.insert-header
> rm -f remove-potcdate.sed
> rm -f stamp-poT
> rm -f core core.* libxine2.po libxine2.1po libxine2.2po *.new.po
> rm -fr *.o
> rm -f Makefile Makefile.in POTFILES *.mo
> make[2]: Leaving directory '/<<PKGBUILDDIR>>/po'
> Making distclean in lib
> make[2]: Entering directory '/<<PKGBUILDDIR>>/lib'
> rm -rf .libs _libs
> test -z "libxineposix.la" || rm -f libxineposix.la
> rm -f *.o
> rm -f *.lo
> rm -f *.tab.c
> test -z "" || rm -f 
> rm -f TAGS ID GTAGS GRTAGS GSYMS GPATH tags
> test . = "." || test -z "" || rm -f 
> rm -f ./so_locations
> rm -f .deps/asprintf.Plo
> rm -f .deps/basename.Plo
> rm -f .deps/dirent_msvc.Plo
> rm -f .deps/gettimeofday.Plo
> rm -f .deps/hstrerror.Plo
> rm -f .deps/memmem.Plo
> rm -f .deps/setenv.Plo
> rm -f .deps/strcasestr.Plo
> rm -f .deps/strlcat.Plo
> rm -f .deps/strlcpy.Plo
> rm -f .deps/strndup.Plo
> rm -f .deps/strpbrk.Plo
> rm -f .deps/strsep.Plo
> rm -f .deps/strtok_r.Plo
> rm -f .deps/swab.Plo
> rm -f .deps/timedlock.Plo
> rm -f .deps/timegm.Plo
> rm -f .deps/unsetenv.Plo
> rm -f Makefile
> make[2]: Leaving directory '/<<PKGBUILDDIR>>/lib'
> Making distclean in src
> make[2]: Entering directory '/<<PKGBUILDDIR>>/src'
> Making distclean in xine-utils
> make[3]: Entering directory '/<<PKGBUILDDIR>>/src/xine-utils'
> rm -rf .libs _libs
> test -z "libxineutils.la libyuv2rgb.la" || rm -f libxineutils.la libyuv2rgb.la
> rm -f *.o
> rm -f *.lo
> rm -f *.tab.c
> test -z "" || rm -f 
>  rm -f xmltest
> rm -f TAGS ID GTAGS GRTAGS GSYMS GPATH tags
> test . = "." || test -z "" || rm -f 
> rm -f ./so_locations
> rm -f ./.deps/array.Plo
> rm -f ./.deps/color.Plo
> rm -f ./.deps/copy.Plo
> rm -f ./.deps/cpu_accel.Plo
> rm -f ./.deps/libyuv2rgb_la-yuv2rgb.Plo
> rm -f ./.deps/libyuv2rgb_la-yuv2rgb_mlib.Plo
> rm -f ./.deps/libyuv2rgb_la-yuv2rgb_mmx.Plo
> rm -f ./.deps/list.Plo
> rm -f ./.deps/memcpy.Plo
> rm -f ./.deps/mfrag.Plo
> rm -f ./.deps/monitor.Plo
> rm -f ./.deps/pool.Plo
> rm -f ./.deps/ppcasm_string.Plo
> rm -f ./.deps/ring_buffer.Plo
> rm -f ./.deps/sorted_array.Plo
> rm -f ./.deps/stree.Plo
> rm -f ./.deps/utils.Plo
> rm -f ./.deps/xine_buffer.Plo
> rm -f ./.deps/xine_check.Plo
> rm -f ./.deps/xine_mutex.Plo
> rm -f ./.deps/xmllexer.Plo
> rm -f ./.deps/xmlparser.Plo
> rm -f ./.deps/xmltest-xmllexer.Po
> rm -f ./.deps/xmltest-xmlparser.Po
> rm -f Makefile
> make[3]: Leaving directory '/<<PKGBUILDDIR>>/src/xine-utils'
> Making distclean in xine-engine
> make[3]: Entering directory '/<<PKGBUILDDIR>>/src/xine-engine'
> test -z "dummy.c" || rm -f dummy.c
> test -z "libxine.la" || rm -f libxine.la
> rm -rf .libs _libs
> rm -f libxine-interface.la
> test -z "libxine-interface.la" || rm -f libxine-interface.la
> rm -f *.o
> rm -f *.lo
> rm -f *.tab.c
> test -z "" || rm -f 
> rm -f TAGS ID GTAGS GRTAGS GSYMS GPATH tags
> test . = "." || test -z "" || rm -f 
> rm -f ./so_locations
> rm -f ./so_locations
> rm -f ./.deps/alphablend.Plo
> rm -f ./.deps/audio_decoder.Plo
> rm -f ./.deps/audio_out.Plo
> rm -f ./.deps/broadcaster.Plo
> rm -f ./.deps/buffer.Plo
> rm -f ./.deps/buffer_types.Plo
> rm -f ./.deps/builtins.Plo
> rm -f ./.deps/configfile.Plo
> rm -f ./.deps/demux.Plo
> rm -f ./.deps/dummy.Plo
> rm -f ./.deps/events.Plo
> rm -f ./.deps/id3.Plo
> rm -f ./.deps/info_helper.Plo
> rm -f ./.deps/input_cache.Plo
> rm -f ./.deps/input_rip.Plo
> rm -f ./.deps/io_helper.Plo
> rm -f ./.deps/load_plugins.Plo
> rm -f ./.deps/metronom.Plo
> rm -f ./.deps/net_buf_ctrl.Plo
> rm -f ./.deps/osd.Plo
> rm -f ./.deps/post.Plo
> rm -f ./.deps/refcounter.Plo
> rm -f ./.deps/resample.Plo
> rm -f ./.deps/scratch.Plo
> rm -f ./.deps/spu.Plo
> rm -f ./.deps/video_decoder.Plo
> rm -f ./.deps/video_out.Plo
> rm -f ./.deps/video_overlay.Plo
> rm -f ./.deps/vo_scale.Plo
> rm -f ./.deps/xine.Plo
> rm -f ./.deps/xine_interface.Plo
> rm -f Makefile
> make[3]: Leaving directory '/<<PKGBUILDDIR>>/src/xine-engine'
> Making distclean in audio_out
> make[3]: Entering directory '/<<PKGBUILDDIR>>/src/audio_out'
> rm -rf .libs _libs
> test -z " xineplug_ao_out_oss.la xineplug_ao_out_alsa.la     
> xineplug_ao_out_pulseaudio.la   xineplug_ao_out_jack.la  " || rm -f  
> xineplug_ao_out_oss.la xineplug_ao_out_alsa.la     
> xineplug_ao_out_pulseaudio.la   xineplug_ao_out_jack.la  
> rm -f *.o
> rm -f *.lo
> rm -f *.tab.c
> test -z "" || rm -f 
> rm -f TAGS ID GTAGS GRTAGS GSYMS GPATH tags
> test . = "." || test -z "" || rm -f 
> rm -f ./so_locations
> rm -f ./.deps/audio_coreaudio_out.Plo
> rm -f ./.deps/audio_file_out.Plo
> rm -f ./.deps/audio_none_out.Plo
> rm -f ./.deps/audio_oss_out.Plo
> rm -f ./.deps/audio_sun_out.Plo
> rm -f ./.deps/xineplug_ao_out_alsa_la-audio_alsa_out.Plo
> rm -f ./.deps/xineplug_ao_out_directx2_la-audio_directx2_out.Plo
> rm -f ./.deps/xineplug_ao_out_directx_la-audio_directx_out.Plo
> rm -f ./.deps/xineplug_ao_out_esd_la-audio_esd_out.Plo
> rm -f ./.deps/xineplug_ao_out_fusionsound_la-audio_fusionsound_out.Plo
> rm -f ./.deps/xineplug_ao_out_jack_la-audio_jack_out.Plo
> rm -f ./.deps/xineplug_ao_out_opensles_la-audio_opensles_out.Plo
> rm -f ./.deps/xineplug_ao_out_pulseaudio_la-audio_pulse_out.Plo
> rm -f ./.deps/xineplug_ao_out_sndio_la-audio_sndio_out.Plo
> rm -f Makefile
> make[3]: Leaving directory '/<<PKGBUILDDIR>>/src/audio_out'
> Making distclean in audio_dec
> make[3]: Entering directory '/<<PKGBUILDDIR>>/src/audio_dec'
> rm -rf .libs _libs
> test -z "xineplug_decode_to_spdif.la xineplug_decode_dvaudio.la 
> xineplug_decode_lpcm.la xineplug_decode_gsm610.la xineplug_decode_mpc.la 
> xineplug_decode_dts.la xineplug_decode_mad.la xineplug_decode_a52.la 
> xineplug_decode_faad.la" || rm -f xineplug_decode_to_spdif.la 
> xineplug_decode_dvaudio.la xineplug_decode_lpcm.la xineplug_decode_gsm610.la 
> xineplug_decode_mpc.la xineplug_decode_dts.la xineplug_decode_mad.la 
> xineplug_decode_a52.la xineplug_decode_faad.la
> rm -f *.o
> rm -f *.lo
> rm -f *.tab.c
> test -z "" || rm -f 
> rm -f TAGS ID GTAGS GRTAGS GSYMS GPATH tags
> test . = "." || test -z "" || rm -f 
> rm -f ./so_locations
> rm -f ./.deps/xine_a52_spdif.Plo
> rm -f ./.deps/xine_lpcm_decoder.Plo
> rm -f ./.deps/xineplug_decode_a52_la-xine_a52_decoder.Plo
> rm -f ./.deps/xineplug_decode_dts_la-xine_dts_decoder.Plo
> rm -f ./.deps/xineplug_decode_dvaudio_la-ff_dvaudio_decoder.Plo
> rm -f ./.deps/xineplug_decode_faad_la-xine_faad_decoder.Plo
> rm -f ./.deps/xineplug_decode_gsm610_la-gsm610.Plo
> rm -f ./.deps/xineplug_decode_mad_la-xine_mad_decoder.Plo
> rm -f ./.deps/xineplug_decode_mpc_la-xine_musepack_decoder.Plo
> rm -f Makefile
> make[3]: Leaving directory '/<<PKGBUILDDIR>>/src/audio_dec'
> Making distclean in video_out
> make[3]: Entering directory '/<<PKGBUILDDIR>>/src/video_out'
> Making distclean in macosx
> make[4]: Entering directory '/<<PKGBUILDDIR>>/src/video_out/macosx'
> test -z "libxineMacOSXVideo.la" || rm -f libxineMacOSXVideo.la
> rm -rf .libs _libs
> rm -f *.o
> rm -f *.lo
> rm -f *.tab.c
> test -z "" || rm -f 
> rm -f TAGS ID GTAGS GRTAGS GSYMS GPATH tags
> test . = "." || test -z "" || rm -f 
> rm -f ./so_locations
> rm -f ./.deps/XineOpenGLView.Plo
> rm -f ./.deps/XineVideoWindow.Plo
> rm -f Makefile
> make[4]: Leaving directory '/<<PKGBUILDDIR>>/src/video_out/macosx'
> make[4]: Entering directory '/<<PKGBUILDDIR>>/src/video_out'
> rm -rf .libs _libs
> test -z "libx11osd.la libxcbosd.la opengl/xine_gl.la vaapi/xine_vaapi.la 
> hw_frame.la" || rm -f libx11osd.la libxcbosd.la opengl/xine_gl.la 
> vaapi/xine_vaapi.la hw_frame.la
> test -z "xineplug_vo_out_xshm.la xineplug_vo_out_xv.la 
> xineplug_vo_out_xvmc.la xineplug_vo_out_opengl.la xineplug_vo_out_opengl2.la  
>   xineplug_vo_out_aa.la xineplug_vo_out_fb.la xineplug_vo_out_directfb.la 
> xineplug_vo_out_xdirectfb.la xineplug_vo_out_sdl.la   xineplug_vo_out_caca.la 
>  xineplug_vo_out_xxmc.la xineplug_vo_out_xcbshm.la xineplug_vo_out_xcbxv.la 
> xineplug_vo_out_vdpau.la xineplug_vo_out_vaapi.la   xineplug_vo_out_raw.la 
> xineplug_vo_gl_glx.la xineplug_vo_gl_egl_wl.la xineplug_vo_gl_egl_x11.la 
> xineplug_hw_frame_vaapi.la xineplug_va_display_x11.la 
> xineplug_va_display_glx.la xineplug_va_display_wl.la 
> xineplug_va_display_drm.la" || rm -f xineplug_vo_out_xshm.la 
> xineplug_vo_out_xv.la xineplug_vo_out_xvmc.la xineplug_vo_out_opengl.la 
> xineplug_vo_out_opengl2.la    xineplug_vo_out_aa.la 
> xineplug_vo_out_fb.la xineplug_vo_out_directfb.la 
> xineplug_vo_out_xdirectfb.la xineplug_vo_out_sdl.la   xineplug_vo_out_caca.la 
>  xineplug_vo_out_xxmc.la xineplug_vo_out_xcbshm.la xineplug_vo_out_xcbxv.la 
> xineplug_vo_out_vdpau.la xineplug_vo_out_vaapi.la   xineplug_vo_out_raw.la 
> xineplug_vo_gl_glx.la xineplug_vo_gl_egl_wl.la xineplug_vo_gl_egl_x11.la 
> xineplug_hw_frame_vaapi.la xineplug_va_display_x11.la 
> xineplug_va_display_glx.la xineplug_va_display_wl.la 
> xineplug_va_display_drm.la
> rm -f *.o
> rm -f *.lo
> rm -f *.tab.c
> test -z "" || rm -f 
> rm -f TAGS ID GTAGS GRTAGS GSYMS GPATH tags
> rm -f opengl/*.o
> test . = "." || test -z "" || rm -f 
> rm -f opengl/.deps/.dirstamp
> rm -f opengl/*.lo
> rm -rf opengl/.libs opengl/_libs
> rm -f ./so_locations opengl/so_locations vaapi/so_locations
> rm -f opengl/.dirstamp
> rm -f ./so_locations
> rm -f vaapi/*.o
> rm -rf vaapi/.libs vaapi/_libs
> rm -f vaapi/.deps/.dirstamp
> rm -f vaapi/*.lo
> rm -f vaapi/.dirstamp
> make[4]: Leaving directory '/<<PKGBUILDDIR>>/src/video_out'
> rm -f ./.deps/hw_frame_la-hw_frame.Plo
> rm -f ./.deps/libx11osd_la-x11osd.Plo
> rm -f ./.deps/libxcbosd_la-xcbosd.Plo
> rm -f ./.deps/video_out_macosx.Plo
> rm -f ./.deps/video_out_none.Plo
> rm -f ./.deps/xineplug_vo_out_aa_la-video_out_aa.Plo
> rm -f ./.deps/xineplug_vo_out_caca_la-video_out_caca.Plo
> rm -f ./.deps/xineplug_vo_out_directfb_la-video_out_directfb.Plo
> rm -f ./.deps/xineplug_vo_out_directx_la-video_out_directx.Plo
> rm -f ./.deps/xineplug_vo_out_fb_la-video_out_fb.Plo
> rm -f ./.deps/xineplug_vo_out_mmal_la-video_out_mmal.Plo
> rm -f ./.deps/xineplug_vo_out_opengl2_la-video_out_opengl2.Plo
> rm -f ./.deps/xineplug_vo_out_opengl_la-video_out_opengl.Plo
> rm -f ./.deps/xineplug_vo_out_pgx32_la-video_out_pgx32.Plo
> rm -f ./.deps/xineplug_vo_out_pgx64_la-video_out_pgx64.Plo
> rm -f ./.deps/xineplug_vo_out_raw_la-video_out_raw.Plo
> rm -f ./.deps/xineplug_vo_out_sdl_la-video_out_sdl.Plo
> rm -f ./.deps/xineplug_vo_out_stk_la-video_out_stk.Plo
> rm -f ./.deps/xineplug_vo_out_vaapi_la-video_out_vaapi.Plo
> rm -f ./.deps/xineplug_vo_out_vdpau_la-video_out_vdpau.Plo
> rm -f ./.deps/xineplug_vo_out_vidix_la-video_out_vidix.Plo
> rm -f ./.deps/xineplug_vo_out_xcbshm_la-video_out_xcbshm.Plo
> rm -f ./.deps/xineplug_vo_out_xcbxv_la-video_out_xcbxv.Plo
> rm -f ./.deps/xineplug_vo_out_xdirectfb_la-video_out_directfb.Plo
> rm -f ./.deps/xineplug_vo_out_xshm_la-video_out_xshm.Plo
> rm -f ./.deps/xineplug_vo_out_xv_la-video_out_xv.Plo
> rm -f ./.deps/xineplug_vo_out_xvmc_la-video_out_xvmc.Plo
> rm -f ./.deps/xineplug_vo_out_xxmc_la-video_out_xxmc.Plo
> rm -f ./.deps/xineplug_vo_out_xxmc_la-xvmc_mocomp.Plo
> rm -f ./.deps/xineplug_vo_out_xxmc_la-xvmc_vld.Plo
> rm -f opengl/.deps/xine_gl_la-xine_gl.Plo
> rm -f opengl/.deps/xineplug_vo_gl_egl_wl_la-xine_egl.Plo
> rm -f opengl/.deps/xineplug_vo_gl_egl_x11_la-xine_egl.Plo
> rm -f opengl/.deps/xineplug_vo_gl_glx_la-xine_glx.Plo
> rm -f vaapi/.deps/xine_vaapi_la-vaapi_frame.Plo
> rm -f vaapi/.deps/xine_vaapi_la-vaapi_util.Plo
> rm -f vaapi/.deps/xine_vaapi_la-xine_va_display.Plo
> rm -f vaapi/.deps/xineplug_hw_frame_vaapi_la-vaapi_egl.Plo
> rm -f vaapi/.deps/xineplug_hw_frame_vaapi_la-xine_hw_frame_vaapi.Plo
> rm -f vaapi/.deps/xineplug_va_display_drm_la-xine_va_display_drm.Plo
> rm -f vaapi/.deps/xineplug_va_display_glx_la-xine_va_display_glx.Plo
> rm -f vaapi/.deps/xineplug_va_display_wl_la-xine_va_display_wl.Plo
> rm -f vaapi/.deps/xineplug_va_display_x11_la-xine_va_display_x11.Plo
> rm -f Makefile
> make[3]: Leaving directory '/<<PKGBUILDDIR>>/src/video_out'
> Making distclean in video_dec
> make[3]: Entering directory '/<<PKGBUILDDIR>>/src/video_dec'
> rm -rf .libs _libs
> test -z "xineplug_decode_image.la  xineplug_decode_dav1d.la 
> xineplug_decode_libaom.la xineplug_decode_libjpeg.la 
> xineplug_decode_libpng.la  xineplug_decode_libvpx.la  
> xineplug_decode_vdpau.la xineplug_decode_rawvideo.la xineplug_decode_mpeg2.la 
> " || rm -f xineplug_decode_image.la  xineplug_decode_dav1d.la 
> xineplug_decode_libaom.la xineplug_decode_libjpeg.la 
> xineplug_decode_libpng.la  xineplug_decode_libvpx.la  
> xineplug_decode_vdpau.la xineplug_decode_rawvideo.la xineplug_decode_mpeg2.la 
> rm -f *.o
> rm -f *.lo
> rm -f *.tab.c
> test -z "" || rm -f 
> rm -f TAGS ID GTAGS GRTAGS GSYMS GPATH tags
> rm -f libmpeg2/*.o
> test . = "." || test -z "" || rm -f 
> rm -rf libmpeg2/.libs libmpeg2/_libs
> rm -f libmpeg2/.deps/.dirstamp
> rm -f libmpeg2/*.lo
> rm -f ./so_locations
> rm -f libmpeg2/.dirstamp
> rm -rf libmpeg2new/.libs libmpeg2new/_libs
> rm -f libmpeg2new/*.o
> rm -f libmpeg2new/.deps/.dirstamp
> rm -f libmpeg2new/*.lo
> rm -rf libmpeg2new/libmpeg2/.libs libmpeg2new/libmpeg2/_libs
> rm -f libmpeg2new/.dirstamp
> rm -f libmpeg2new/libmpeg2/*.o
> rm -rf libvdpau/.libs libvdpau/_libs
> rm -f libmpeg2new/libmpeg2/.deps/.dirstamp
> rm -f libmpeg2new/libmpeg2/*.lo
> rm -f libmpeg2new/libmpeg2/.dirstamp
> rm -f libvdpau/*.o
> rm -f libvdpau/.deps/.dirstamp
> rm -f libvdpau/*.lo
> rm -f libvdpau/.dirstamp
> rm -f ./.deps/bitplane.Plo
> rm -f ./.deps/group_raw.Plo
> rm -f ./.deps/rgb.Plo
> rm -f ./.deps/xineplug_decode_dav1d_la-dav1d.Plo
> rm -f ./.deps/xineplug_decode_gdk_pixbuf_la-gdkpixbuf.Plo
> rm -f ./.deps/xineplug_decode_image_la-image.Plo
> rm -f ./.deps/xineplug_decode_libaom_la-libaom.Plo
> rm -f ./.deps/xineplug_decode_libjpeg_la-libjpeg.Plo
> rm -f ./.deps/xineplug_decode_libmmal_la-mmal.Plo
> rm -f ./.deps/xineplug_decode_libopenhevc_la-libopenhevc.Plo
> rm -f ./.deps/xineplug_decode_libpng_la-libpng.Plo
> rm -f ./.deps/xineplug_decode_libvpx_la-libvpx.Plo
> rm -f ./.deps/yuv.Plo
> rm -f libmpeg2/.deps/xineplug_decode_mpeg2_la-cpu_state.Plo
> rm -f libmpeg2/.deps/xineplug_decode_mpeg2_la-decode.Plo
> rm -f libmpeg2/.deps/xineplug_decode_mpeg2_la-header.Plo
> rm -f libmpeg2/.deps/xineplug_decode_mpeg2_la-idct.Plo
> rm -f libmpeg2/.deps/xineplug_decode_mpeg2_la-idct_altivec.Plo
> rm -f libmpeg2/.deps/xineplug_decode_mpeg2_la-idct_mlib.Plo
> rm -f libmpeg2/.deps/xineplug_decode_mpeg2_la-idct_mmx.Plo
> rm -f libmpeg2/.deps/xineplug_decode_mpeg2_la-libmpeg2_accel.Plo
> rm -f libmpeg2/.deps/xineplug_decode_mpeg2_la-motion_comp.Plo
> rm -f libmpeg2/.deps/xineplug_decode_mpeg2_la-motion_comp_altivec.Plo
> rm -f libmpeg2/.deps/xineplug_decode_mpeg2_la-motion_comp_mlib.Plo
> rm -f libmpeg2/.deps/xineplug_decode_mpeg2_la-motion_comp_mmx.Plo
> rm -f libmpeg2/.deps/xineplug_decode_mpeg2_la-motion_comp_vis.Plo
> rm -f libmpeg2/.deps/xineplug_decode_mpeg2_la-slice.Plo
> rm -f libmpeg2/.deps/xineplug_decode_mpeg2_la-slice_xvmc.Plo
> rm -f libmpeg2/.deps/xineplug_decode_mpeg2_la-slice_xvmc_vld.Plo
> rm -f libmpeg2/.deps/xineplug_decode_mpeg2_la-stats.Plo
> rm -f libmpeg2/.deps/xineplug_decode_mpeg2_la-xine_mpeg2_decoder.Plo
> rm -f libmpeg2new/.deps/xineplug_decode_mpeg2new_la-xine_mpeg2new_decoder.Plo
> rm -f libmpeg2new/libmpeg2/.deps/xineplug_decode_mpeg2new_la-alloc.Plo
> rm -f libmpeg2new/libmpeg2/.deps/xineplug_decode_mpeg2new_la-cpu_accel.Plo
> rm -f libmpeg2new/libmpeg2/.deps/xineplug_decode_mpeg2new_la-cpu_state.Plo
> rm -f libmpeg2new/libmpeg2/.deps/xineplug_decode_mpeg2new_la-decode.Plo
> rm -f libmpeg2new/libmpeg2/.deps/xineplug_decode_mpeg2new_la-header.Plo
> rm -f libmpeg2new/libmpeg2/.deps/xineplug_decode_mpeg2new_la-idct.Plo
> rm -f libmpeg2new/libmpeg2/.deps/xineplug_decode_mpeg2new_la-idct_alpha.Plo
> rm -f libmpeg2new/libmpeg2/.deps/xineplug_decode_mpeg2new_la-idct_altivec.Plo
> rm -f libmpeg2new/libmpeg2/.deps/xineplug_decode_mpeg2new_la-idct_mmx.Plo
> rm -f libmpeg2new/libmpeg2/.deps/xineplug_decode_mpeg2new_la-motion_comp.Plo
> rm -f 
> libmpeg2new/libmpeg2/.deps/xineplug_decode_mpeg2new_la-motion_comp_alpha.Plo
> rm -f 
> libmpeg2new/libmpeg2/.deps/xineplug_decode_mpeg2new_la-motion_comp_altivec.Plo
> rm -f 
> libmpeg2new/libmpeg2/.deps/xineplug_decode_mpeg2new_la-motion_comp_mmx.Plo
> rm -f 
> libmpeg2new/libmpeg2/.deps/xineplug_decode_mpeg2new_la-motion_comp_vis.Plo
> rm -f libmpeg2new/libmpeg2/.deps/xineplug_decode_mpeg2new_la-slice.Plo
> rm -f libvdpau/.deps/xineplug_decode_vdpau_la-alterh264_decode.Plo
> rm -f libvdpau/.deps/xineplug_decode_vdpau_la-group_vdpau.Plo
> rm -f libvdpau/.deps/xineplug_decode_vdpau_la-vdec_hw_h264.Plo
> rm -f libvdpau/.deps/xineplug_decode_vdpau_la-vdpau_h264.Plo
> rm -f libvdpau/.deps/xineplug_decode_vdpau_la-vdpau_mpeg12.Plo
> rm -f libvdpau/.deps/xineplug_decode_vdpau_la-vdpau_mpeg4.Plo
> rm -f libvdpau/.deps/xineplug_decode_vdpau_la-vdpau_vc1.Plo
> rm -f Makefile
> make[3]: Leaving directory '/<<PKGBUILDDIR>>/src/video_dec'
> Making distclean in spu_dec
> make[3]: Entering directory '/<<PKGBUILDDIR>>/src/spu_dec'
> rm -rf .libs _libs
> test -z "xineplug_decode_spucc.la xineplug_decode_spucmml.la 
> xineplug_decode_spu.la xineplug_decode_spudvb.la xineplug_decode_spuhdmv.la 
> xineplug_sputext.la" || rm -f xineplug_decode_spucc.la 
> xineplug_decode_spucmml.la xineplug_decode_spu.la xineplug_decode_spudvb.la 
> xineplug_decode_spuhdmv.la xineplug_sputext.la
> rm -f *.o
> rm -f *.lo
> rm -f *.tab.c
> test -z "" || rm -f 
> rm -f TAGS ID GTAGS GRTAGS GSYMS GPATH tags
> test . = "." || test -z "" || rm -f 
> rm -f ./so_locations
> rm -f ./.deps/cmml_decoder.Plo
> rm -f ./.deps/spudvb_decoder.Plo
> rm -f ./.deps/spuhdmv_decoder.Plo
> rm -f ./.deps/sputext_decoder.Plo
> rm -f ./.deps/sputext_demuxer.Plo
> rm -f ./.deps/xineplug_decode_spu_la-nav_read.Plo
> rm -f ./.deps/xineplug_decode_spu_la-spu_decoder.Plo
> rm -f ./.deps/xineplug_decode_spu_la-spudec.Plo
> rm -f ./.deps/xineplug_decode_spucc_la-cc_decoder.Plo
> rm -f ./.deps/xineplug_decode_spucc_la-xine_cc_decoder.Plo
> rm -f Makefile
> make[3]: Leaving directory '/<<PKGBUILDDIR>>/src/spu_dec'
> Making distclean in dxr3
> make[3]: Entering directory '/<<PKGBUILDDIR>>/src/dxr3'
> rm -rf .libs _libs
> test -z "xineplug_dxr3.la" || rm -f xineplug_dxr3.la
> rm -f *.o
> rm -f *.lo
> rm -f *.tab.c
> test -z "" || rm -f 
> rm -f TAGS ID GTAGS GRTAGS GSYMS GPATH tags
> test . = "." || test -z "" || rm -f 
> rm -f ./so_locations
> rm -f ./.deps/xineplug_dxr3_la-compat.Plo
> rm -f ./.deps/xineplug_dxr3_la-dxr3_decode_spu.Plo
> rm -f ./.deps/xineplug_dxr3_la-dxr3_decode_video.Plo
> rm -f ./.deps/xineplug_dxr3_la-dxr3_mpeg_encoders.Plo
> rm -f ./.deps/xineplug_dxr3_la-dxr3_scr.Plo
> rm -f ./.deps/xineplug_dxr3_la-dxr3_spu_encoder.Plo
> rm -f ./.deps/xineplug_dxr3_la-ffmpeg_encoder.Plo
> rm -f ./.deps/xineplug_dxr3_la-group_dxr3.Plo
> rm -f ./.deps/xineplug_dxr3_la-nav_read.Plo
> rm -f ./.deps/xineplug_dxr3_la-video_out_dxr3.Plo
> rm -f Makefile
> make[3]: Leaving directory '/<<PKGBUILDDIR>>/src/dxr3'
> Making distclean in input
> make[3]: Entering directory '/<<PKGBUILDDIR>>/src/input'
> Making distclean in libdvdnav
> make[4]: Entering directory '/<<PKGBUILDDIR>>/src/input/libdvdnav'
> rm -rf .libs _libs
> test -z "libdvdnav.la" || rm -f libdvdnav.la
> rm -f *.o
> rm -f *.lo
> rm -f *.tab.c
> test -z "" || rm -f 
> rm -f TAGS ID GTAGS GRTAGS GSYMS GPATH tags
> test . = "." || test -z "" || rm -f 
> rm -f ./so_locations
> rm -f ./.deps/decoder.Plo
> rm -f ./.deps/dvd_input.Plo
> rm -f ./.deps/dvd_reader.Plo
> rm -f ./.deps/dvd_udf.Plo
> rm -f ./.deps/dvdnav.Plo
> rm -f ./.deps/highlight.Plo
> rm -f ./.deps/ifo_read.Plo
> rm -f ./.deps/md5.Plo
> rm -f ./.deps/nav_print.Plo
> rm -f ./.deps/nav_read.Plo
> rm -f ./.deps/navigation.Plo
> rm -f ./.deps/read_cache.Plo
> rm -f ./.deps/remap.Plo
> rm -f ./.deps/searching.Plo
> rm -f ./.deps/settings.Plo
> rm -f ./.deps/vm.Plo
> rm -f ./.deps/vmcmd.Plo
> rm -f Makefile
> make[4]: Leaving directory '/<<PKGBUILDDIR>>/src/input/libdvdnav'
> make[4]: Entering directory '/<<PKGBUILDDIR>>/src/input'
> rm -rf .libs _libs
> test -z "http_helper.la input_helper.la media_helper.la xine_tls.la 
> librtsp.la libreal.la" || rm -f http_helper.la input_helper.la 
> media_helper.la xine_tls.la librtsp.la libreal.la
> test -z "   xineplug_inp_dvd.la xineplug_inp_vcd.la xineplug_inp_vcdo.la  
> xineplug_inp_v4l2.la   xineplug_inp_smb.la  xineplug_inp_mms.la 
> xineplug_inp_rtp.la xineplug_inp_network.la xineplug_inp_pvr.la 
> xineplug_inp_dvb.la xineplug_inp_bluray.la  xineplug_inp_cdda.la" || rm -f    
> xineplug_inp_dvd.la xineplug_inp_vcd.la xineplug_inp_vcdo.la  
> xineplug_inp_v4l2.la   xineplug_inp_smb.la  xineplug_inp_mms.la 
> xineplug_inp_rtp.la xineplug_inp_network.la xineplug_inp_pvr.la 
> xineplug_inp_dvb.la xineplug_inp_bluray.la  xineplug_inp_cdda.la
> rm -f *.o
> rm -f *.lo
> rm -f *.tab.c
> test -z "" || rm -f 
> rm -f TAGS ID GTAGS GRTAGS GSYMS GPATH tags
> rm -f libreal/*.o
> test . = "." || test -z "" || rm -f 
> rm -f libreal/.deps/.dirstamp
> rm -rf libreal/.libs libreal/_libs
> rm -f libreal/*.lo
> rm -f libreal/.dirstamp
> rm -f ./so_locations
> rm -f librtsp/*.o
> rm -f ./so_locations
> rm -rf librtsp/.libs librtsp/_libs
> rm -f librtsp/.deps/.dirstamp
> rm -f librtsp/*.lo
> rm -rf tls/.libs tls/_libs
> rm -f librtsp/.dirstamp
> rm -f tls/*.o
> rm -rf vcd/.libs vcd/_libs
> rm -f tls/.deps/.dirstamp
> rm -f tls/*.lo
> rm -f tls/.dirstamp
> rm -f vcd/*.o
> rm -f vcd/.deps/.dirstamp
> rm -f vcd/*.lo
> rm -f vcd/.dirstamp
> make[4]: Leaving directory '/<<PKGBUILDDIR>>/src/input'
> rm -f ./.deps/http_helper.Plo
> rm -f ./.deps/input_file.Plo
> rm -f ./.deps/input_helper.Plo
> rm -f ./.deps/input_mms.Plo
> rm -f ./.deps/input_pvr.Plo
> rm -f ./.deps/input_rtp.Plo
> rm -f ./.deps/input_stdin_fifo.Plo
> rm -f ./.deps/input_test.Plo
> rm -f ./.deps/input_vcd.Plo
> rm -f ./.deps/media_helper.Plo
> rm -f ./.deps/mms.Plo
> rm -f ./.deps/mmsh.Plo
> rm -f ./.deps/xineplug_inp_bluray_la-input_bluray.Plo
> rm -f ./.deps/xineplug_inp_cdda_la-input_cdda.Plo
> rm -f ./.deps/xineplug_inp_crypto_la-input_crypto.Plo
> rm -f ./.deps/xineplug_inp_dvb_la-input_dvb.Plo
> rm -f ./.deps/xineplug_inp_dvd_la-input_dvd.Plo
> rm -f ./.deps/xineplug_inp_gnome_vfs_la-input_gnome_vfs.Plo
> rm -f ./.deps/xineplug_inp_network_la-group_network.Plo
> rm -f ./.deps/xineplug_inp_network_la-input_ftp.Plo
> rm -f ./.deps/xineplug_inp_network_la-input_hls.Plo
> rm -f ./.deps/xineplug_inp_network_la-input_http.Plo
> rm -f ./.deps/xineplug_inp_network_la-input_mpegdash.Plo
> rm -f ./.deps/xineplug_inp_network_la-input_net.Plo
> rm -f ./.deps/xineplug_inp_network_la-input_pnm.Plo
> rm -f ./.deps/xineplug_inp_network_la-input_rtsp.Plo
> rm -f ./.deps/xineplug_inp_network_la-pnm.Plo
> rm -f ./.deps/xineplug_inp_nfs_la-input_nfs.Plo
> rm -f ./.deps/xineplug_inp_smb_la-input_smb.Plo
> rm -f ./.deps/xineplug_inp_ssh_la-input_ssh.Plo
> rm -f ./.deps/xineplug_inp_v4l2_la-input_v4l2.Plo
> rm -f ./.deps/xineplug_inp_v4l_la-input_v4l.Plo
> rm -f libreal/.deps/la-asmrp.Plo
> rm -f libreal/.deps/la-real.Plo
> rm -f libreal/.deps/la-rmff.Plo
> rm -f libreal/.deps/la-sdpplin.Plo
> rm -f librtsp/.deps/la-rtsp.Plo
> rm -f librtsp/.deps/la-rtsp_session.Plo
> rm -f tls/.deps/xine_tls_la-xine_tls.Plo
> rm -f tls/.deps/xineplug_tls_gnutls_la-tls_gnutls.Plo
> rm -f tls/.deps/xineplug_tls_openssl_la-tls_openssl.Plo
> rm -f vcd/.deps/xineplug_inp_vcd_la-vcdio.Plo
> rm -f vcd/.deps/xineplug_inp_vcd_la-vcdplayer.Plo
> rm -f vcd/.deps/xineplug_inp_vcd_la-xineplug_inp_vcd.Plo
> rm -f Makefile
> make[3]: Leaving directory '/<<PKGBUILDDIR>>/src/input'
> Making distclean in demuxers
> make[3]: Entering directory '/<<PKGBUILDDIR>>/src/demuxers'
> rm -rf .libs _libs
> test -z "libasfheader.la" || rm -f libasfheader.la
> test -z "xineplug_dmx_asf.la xineplug_dmx_mng.la xineplug_dmx_image.la 
> xineplug_dmx_modplug.la xineplug_dmx_audio.la xineplug_dmx_fli.la 
> xineplug_dmx_games.la xineplug_dmx_nsv.la xineplug_dmx_playlist.la 
> xineplug_dmx_pva.la xineplug_dmx_slave.la xineplug_dmx_video.la" || rm -f 
> xineplug_dmx_asf.la xineplug_dmx_mng.la xineplug_dmx_image.la 
> xineplug_dmx_modplug.la xineplug_dmx_audio.la xineplug_dmx_fli.la 
> xineplug_dmx_games.la xineplug_dmx_nsv.la xineplug_dmx_playlist.la 
> xineplug_dmx_pva.la xineplug_dmx_slave.la xineplug_dmx_video.la
> rm -f *.o
> rm -f *.lo
> rm -f *.tab.c
> test -z "" || rm -f 
> rm -f TAGS ID GTAGS GRTAGS GSYMS GPATH tags
> test . = "." || test -z "" || rm -f 
> rm -f ./so_locations
> rm -f ./so_locations
> rm -f ./.deps/asfheader.Plo
> rm -f ./.deps/demux_4xm.Plo
> rm -f ./.deps/demux_aac.Plo
> rm -f ./.deps/demux_ac3.Plo
> rm -f ./.deps/demux_aiff.Plo
> rm -f ./.deps/demux_asf.Plo
> rm -f ./.deps/demux_aud.Plo
> rm -f ./.deps/demux_cdda.Plo
> rm -f ./.deps/demux_dts.Plo
> rm -f ./.deps/demux_eawve.Plo
> rm -f ./.deps/demux_film.Plo
> rm -f ./.deps/demux_flac.Plo
> rm -f ./.deps/demux_fli.Plo
> rm -f ./.deps/demux_idcin.Plo
> rm -f ./.deps/demux_image.Plo
> rm -f ./.deps/demux_ipmovie.Plo
> rm -f ./.deps/demux_mpc.Plo
> rm -f ./.deps/demux_mpgaudio.Plo
> rm -f ./.deps/demux_nsv.Plo
> rm -f ./.deps/demux_playlist.Plo
> rm -f ./.deps/demux_pva.Plo
> rm -f ./.deps/demux_realaudio.Plo
> rm -f ./.deps/demux_roq.Plo
> rm -f ./.deps/demux_shn.Plo
> rm -f ./.deps/demux_slave.Plo
> rm -f ./.deps/demux_smjpeg.Plo
> rm -f ./.deps/demux_snd.Plo
> rm -f ./.deps/demux_str.Plo
> rm -f ./.deps/demux_tta.Plo
> rm -f ./.deps/demux_vmd.Plo
> rm -f ./.deps/demux_voc.Plo
> rm -f ./.deps/demux_vox.Plo
> rm -f ./.deps/demux_vqa.Plo
> rm -f ./.deps/demux_wav.Plo
> rm -f ./.deps/demux_wc3movie.Plo
> rm -f ./.deps/group_audio.Plo
> rm -f ./.deps/group_games.Plo
> rm -f ./.deps/xineplug_dmx_mng_la-demux_mng.Plo
> rm -f ./.deps/xineplug_dmx_modplug_la-demux_mod.Plo
> rm -f ./.deps/xineplug_dmx_video_la-demux_avi.Plo
> rm -f ./.deps/xineplug_dmx_video_la-demux_elem.Plo
> rm -f ./.deps/xineplug_dmx_video_la-demux_flv.Plo
> rm -f ./.deps/xineplug_dmx_video_la-demux_iff.Plo
> rm -f ./.deps/xineplug_dmx_video_la-demux_ivf.Plo
> rm -f ./.deps/xineplug_dmx_video_la-demux_matroska-chapters.Plo
> rm -f ./.deps/xineplug_dmx_video_la-demux_matroska.Plo
> rm -f ./.deps/xineplug_dmx_video_la-demux_mpeg.Plo
> rm -f ./.deps/xineplug_dmx_video_la-demux_mpeg_block.Plo
> rm -f ./.deps/xineplug_dmx_video_la-demux_mpeg_pes.Plo
> rm -f ./.deps/xineplug_dmx_video_la-demux_qt.Plo
> rm -f ./.deps/xineplug_dmx_video_la-demux_rawdv.Plo
> rm -f ./.deps/xineplug_dmx_video_la-demux_real.Plo
> rm -f ./.deps/xineplug_dmx_video_la-demux_ts.Plo
> rm -f ./.deps/xineplug_dmx_video_la-demux_vc1es.Plo
> rm -f ./.deps/xineplug_dmx_video_la-demux_yuv4mpeg2.Plo
> rm -f ./.deps/xineplug_dmx_video_la-demux_yuv_frames.Plo
> rm -f ./.deps/xineplug_dmx_video_la-ebml.Plo
> rm -f ./.deps/xineplug_dmx_video_la-group_video.Plo
> rm -f Makefile
> make[3]: Leaving directory '/<<PKGBUILDDIR>>/src/demuxers'
> Making distclean in libw32dll
> make[3]: Entering directory '/<<PKGBUILDDIR>>/src/libw32dll'
> rm -rf .libs _libs
> test -z "" || rm -f 
> test -z "" || rm -f 
> rm -f *.o
> rm -f *.lo
> rm -f *.tab.c
> test -z "" || rm -f 
> rm -rf DirectShow/.libs DirectShow/_libs
> rm -f TAGS ID GTAGS GRTAGS GSYMS GPATH tags
> test . = "." || test -z "" || rm -f 
> rm -f DirectShow/*.o
> rm -rf dmo/.libs dmo/_libs
> rm -f DirectShow/.deps/.dirstamp
> rm -f DirectShow/*.lo
> rm -rf wine/.libs wine/_libs
> rm -f dmo/*.o
> rm -f DirectShow/.dirstamp
> rm -f dmo/*.lo
> rm -f dmo/.deps/.dirstamp
> rm -f wine/*.o
> rm -f dmo/.dirstamp
> rm -f wine/*.lo
> rm -f wine/.deps/.dirstamp
> rm -f wine/.dirstamp
> rm -f ./.deps/xineplug_decode_w32dll_la-group_w32.Plo
> rm -f ./.deps/xineplug_decode_w32dll_la-qt_decoder.Plo
> rm -f ./.deps/xineplug_decode_w32dll_la-w32codec.Plo
> rm -f DirectShow/.deps/libds_filter_la-DS_AudioDecoder.Plo
> rm -f DirectShow/.deps/libds_filter_la-DS_Filter.Plo
> rm -f DirectShow/.deps/libds_filter_la-DS_VideoDecoder.Plo
> rm -f DirectShow/.deps/libds_filter_la-allocator.Plo
> rm -f DirectShow/.deps/libds_filter_la-cmediasample.Plo
> rm -f DirectShow/.deps/libds_filter_la-guids.Plo
> rm -f DirectShow/.deps/libds_filter_la-inputpin.Plo
> rm -f DirectShow/.deps/libds_filter_la-outputpin.Plo
> rm -f dmo/.deps/libdmo_filter_la-DMO_AudioDecoder.Plo
> rm -f dmo/.deps/libdmo_filter_la-DMO_VideoDecoder.Plo
> rm -f dmo/.deps/libdmo_filter_la-buffer.Plo
> rm -f dmo/.deps/libdmo_filter_la-dmo.Plo
> rm -f dmo/.deps/libdmo_filter_la-dmo_guids.Plo
> rm -f wine/.deps/libwine_la-afl.Plo
> rm -f wine/.deps/libwine_la-driver.Plo
> rm -f wine/.deps/libwine_la-elfdll.Plo
> rm -f wine/.deps/libwine_la-ext.Plo
> rm -f wine/.deps/libwine_la-ldt_keeper.Plo
> rm -f wine/.deps/libwine_la-module.Plo
> rm -f wine/.deps/libwine_la-pe_image.Plo
> rm -f wine/.deps/libwine_la-pe_resource.Plo
> rm -f wine/.deps/libwine_la-registry.Plo
> rm -f wine/.deps/libwine_la-resource.Plo
> rm -f wine/.deps/libwine_la-vfl.Plo
> rm -f wine/.deps/libwine_la-win32.Plo
> rm -f wine/.deps/libwine_la-wrapper.Plo
> rm -f Makefile
> make[3]: Leaving directory '/<<PKGBUILDDIR>>/src/libw32dll'
> Making distclean in libreal
> make[3]: Entering directory '/<<PKGBUILDDIR>>/src/libreal'
> rm -rf .libs _libs
> test -z "xineplug_decode_real.la" || rm -f xineplug_decode_real.la
> rm -f *.o
> rm -f *.lo
> rm -f *.tab.c
> test -z "" || rm -f 
> rm -f TAGS ID GTAGS GRTAGS GSYMS GPATH tags
> test . = "." || test -z "" || rm -f 
> rm -f ./so_locations
> rm -f ./.deps/real_common.Plo
> rm -f ./.deps/xine_real_audio_decoder.Plo
> rm -f ./.deps/xine_real_video_decoder.Plo
> rm -f Makefile
> make[3]: Leaving directory '/<<PKGBUILDDIR>>/src/libreal'
> Making distclean in post
> make[3]: Entering directory '/<<PKGBUILDDIR>>/src/post'
> rm -rf .libs _libs
> test -z "libdeinterlaceplugins_O1.la libdeinterlaceplugins.la 
> libpost_planar_x86.la libpost_goom_asm.la" || rm -f 
> libdeinterlaceplugins_O1.la libdeinterlaceplugins.la libpost_planar_x86.la 
> libpost_goom_asm.la
> test -z "xineplug_post_audio_filters.la xineplug_post_goom.la 
> xineplug_post_mosaico.la xineplug_post_planar.la xineplug_post_switch.la 
> xineplug_post_tvtime.la xineplug_post_visualizations.la" || rm -f 
> xineplug_post_audio_filters.la xineplug_post_goom.la xineplug_post_mosaico.la 
> xineplug_post_planar.la xineplug_post_switch.la xineplug_post_tvtime.la 
> xineplug_post_visualizations.la
> rm -f *.o
> rm -f *.lo
> rm -f *.tab.c
> test -z "" || rm -f 
> rm -f TAGS ID GTAGS GRTAGS GSYMS GPATH tags
> rm -f audio/*.o
> test . = "." || test -z "" || rm -f 
> rm -rf audio/.libs audio/_libs
> rm -f audio/.deps/.dirstamp
> rm -f audio/*.lo
> rm -rf deinterlace/.libs deinterlace/_libs
> rm -f audio/.dirstamp
> rm -f deinterlace/*.o
> rm -f ./so_locations
> rm -rf deinterlace/plugins/.libs deinterlace/plugins/_libs
> rm -f ./so_locations
> rm -f deinterlace/.deps/.dirstamp
> rm -f deinterlace/*.lo
> rm -rf goom/.libs goom/_libs
> rm -f deinterlace/.dirstamp
> rm -f deinterlace/plugins/*.o
> rm -f deinterlace/plugins/.deps/.dirstamp
> rm -rf mosaico/.libs mosaico/_libs
> rm -f deinterlace/plugins/*.lo
> rm -f deinterlace/plugins/.dirstamp
> rm -rf planar/.libs planar/_libs
> rm -f goom/*.o
> rm -f goom/.deps/.dirstamp
> rm -f goom/*.lo
> rm -rf planar/x86/.libs planar/x86/_libs
> rm -f goom/.dirstamp
> rm -f mosaico/*.o
> rm -rf visualizations/.libs visualizations/_libs
> rm -f mosaico/.deps/.dirstamp
> rm -f mosaico/*.lo
> rm -f mosaico/.dirstamp
> rm -f planar/*.o
> rm -f planar/.deps/.dirstamp
> rm -f planar/*.lo
> rm -f planar/.dirstamp
> rm -f planar/x86/*.o
> rm -f planar/x86/.deps/.dirstamp
> rm -f planar/x86/*.lo
> rm -f planar/x86/.dirstamp
> rm -f visualizations/*.o
> rm -f visualizations/.deps/.dirstamp
> rm -f visualizations/*.lo
> rm -f visualizations/.dirstamp
> rm -f audio/.deps/audio_filters.Plo
> rm -f audio/.deps/filter.Plo
> rm -f audio/.deps/stretch.Plo
> rm -f audio/.deps/upmix.Plo
> rm -f audio/.deps/upmix_mono.Plo
> rm -f audio/.deps/volnorm.Plo
> rm -f audio/.deps/window.Plo
> rm -f deinterlace/.deps/xineplug_post_tvtime_la-deinterlace.Plo
> rm -f deinterlace/.deps/xineplug_post_tvtime_la-pulldown.Plo
> rm -f deinterlace/.deps/xineplug_post_tvtime_la-speedy.Plo
> rm -f deinterlace/.deps/xineplug_post_tvtime_la-tvtime.Plo
> rm -f deinterlace/.deps/xineplug_post_tvtime_la-xine_plugin.Plo
> rm -f deinterlace/plugins/.deps/libdeinterlaceplugins_O1_la-greedy2frame.Plo
> rm -f deinterlace/plugins/.deps/libdeinterlaceplugins_O1_la-kdetv_greedyh.Plo
> rm -f deinterlace/plugins/.deps/libdeinterlaceplugins_la-double.Plo
> rm -f deinterlace/plugins/.deps/libdeinterlaceplugins_la-greedy.Plo
> rm -f deinterlace/plugins/.deps/libdeinterlaceplugins_la-greedy2frame.Plo
> rm -f deinterlace/plugins/.deps/libdeinterlaceplugins_la-kdetv_tomsmocomp.Plo
> rm -f deinterlace/plugins/.deps/libdeinterlaceplugins_la-linear.Plo
> rm -f deinterlace/plugins/.deps/libdeinterlaceplugins_la-linearblend.Plo
> rm -f deinterlace/plugins/.deps/libdeinterlaceplugins_la-scalerbob.Plo
> rm -f deinterlace/plugins/.deps/libdeinterlaceplugins_la-vfir.Plo
> rm -f deinterlace/plugins/.deps/libdeinterlaceplugins_la-weave.Plo
> rm -f goom/.deps/config_param.Plo
> rm -f goom/.deps/convolve_fx.Plo
> rm -f goom/.deps/cpu_info.Plo
> rm -f goom/.deps/drawmethods.Plo
> rm -f goom/.deps/filters.Plo
> rm -f goom/.deps/flying_stars_fx.Plo
> rm -f goom/.deps/gfontlib.Plo
> rm -f goom/.deps/goom_core.Plo
> rm -f goom/.deps/goom_tools.Plo
> rm -f goom/.deps/graphic.Plo
> rm -f goom/.deps/ifs.Plo
> rm -f goom/.deps/libpost_goom_asm_la-xmmx.Plo
> rm -f goom/.deps/lines.Plo
> rm -f goom/.deps/mmx.Plo
> rm -f goom/.deps/plugin_info.Plo
> rm -f goom/.deps/sound_tester.Plo
> rm -f goom/.deps/surf3d.Plo
> rm -f goom/.deps/tentacle3d.Plo
> rm -f goom/.deps/v3d.Plo
> rm -f goom/.deps/xine_goom.Plo
> rm -f mosaico/.deps/mosaico.Plo
> rm -f mosaico/.deps/switch.Plo
> rm -f planar/.deps/xineplug_post_planar_la-boxblur.Plo
> rm -f planar/.deps/xineplug_post_planar_la-denoise3d.Plo
> rm -f planar/.deps/xineplug_post_planar_la-eq.Plo
> rm -f planar/.deps/xineplug_post_planar_la-eq2.Plo
> rm -f planar/.deps/xineplug_post_planar_la-expand.Plo
> rm -f planar/.deps/xineplug_post_planar_la-fill.Plo
> rm -f planar/.deps/xineplug_post_planar_la-invert.Plo
> rm -f planar/.deps/xineplug_post_planar_la-noise.Plo
> rm -f planar/.deps/xineplug_post_planar_la-planar.Plo
> rm -f planar/.deps/xineplug_post_planar_la-pp.Plo
> rm -f planar/.deps/xineplug_post_planar_la-unsharp.Plo
> rm -f planar/x86/.deps/libpost_planar_x86_la-noise.Plo
> rm -f visualizations/.deps/fft.Plo
> rm -f visualizations/.deps/fftgraph.Plo
> rm -f visualizations/.deps/fftscope.Plo
> rm -f visualizations/.deps/oscope.Plo
> rm -f visualizations/.deps/tdaudioanalyzer.Plo
> rm -f visualizations/.deps/visualizations.Plo
> rm -f Makefile
> make[3]: Leaving directory '/<<PKGBUILDDIR>>/src/post'
> Making distclean in combined
> make[3]: Entering directory '/<<PKGBUILDDIR>>/src/combined'
> Making distclean in ffmpeg
> make[4]: Entering directory '/<<PKGBUILDDIR>>/src/combined/ffmpeg'
> rm -rf .libs _libs
> test -z "xineplug_decode_ff.la" || rm -f xineplug_decode_ff.la
> rm -f *.o
> rm -f *.lo
> rm -f *.tab.c
> test -z "" || rm -f 
> rm -f TAGS ID GTAGS GRTAGS GSYMS GPATH tags
> test . = "." || test -z "" || rm -f 
> test -z "avcodec_video.list avcodec_audio.list ff_video_list.h 
> ff_audio_list.h" || rm -f avcodec_video.list avcodec_audio.list 
> ff_video_list.h ff_audio_list.h
> rm -f ./so_locations
> rm -f ./.deps/xineplug_decode_ff_la-demux_avformat.Plo
> rm -f ./.deps/xineplug_decode_ff_la-ff_audio_decoder.Plo
> rm -f ./.deps/xineplug_decode_ff_la-ff_mpeg_parser.Plo
> rm -f ./.deps/xineplug_decode_ff_la-ff_video_decoder.Plo
> rm -f ./.deps/xineplug_decode_ff_la-ffmpeg_decoder.Plo
> rm -f ./.deps/xineplug_decode_ff_la-input_avio.Plo
> rm -f Makefile
> make[4]: Leaving directory '/<<PKGBUILDDIR>>/src/combined/ffmpeg'
> make[4]: Entering directory '/<<PKGBUILDDIR>>/src/combined'
> rm -rf .libs _libs
> test -z "xineplug_wavpack.la xineplug_flac.la  xineplug_xiph.la 
> xineplug_xiph.la xineplug_xiph.la" || rm -f xineplug_wavpack.la 
> xineplug_flac.la  xineplug_xiph.la xineplug_xiph.la xineplug_xiph.la
> rm -f *.o
> rm -f *.lo
> rm -f *.tab.c
> test -z "" || rm -f 
> rm -f TAGS ID GTAGS GRTAGS GSYMS GPATH tags
> test . = "." || test -z "" || rm -f 
> rm -f ./so_locations
> make[4]: Leaving directory '/<<PKGBUILDDIR>>/src/combined'
> rm -f ./.deps/xineplug_flac_la-flac_decoder.Plo
> rm -f ./.deps/xineplug_flac_la-flac_demuxer.Plo
> rm -f ./.deps/xineplug_nsf_la-nsf_combined.Plo
> rm -f ./.deps/xineplug_nsf_la-nsf_decoder.Plo
> rm -f ./.deps/xineplug_nsf_la-nsf_demuxer.Plo
> rm -f ./.deps/xineplug_wavpack_la-wavpack_combined.Plo
> rm -f ./.deps/xineplug_wavpack_la-wavpack_decoder.Plo
> rm -f ./.deps/xineplug_wavpack_la-wavpack_demuxer.Plo
> rm -f ./.deps/xineplug_xiph_la-ogg_combined.Plo
> rm -f ./.deps/xineplug_xiph_la-xine_ogg_demuxer.Plo
> rm -f ./.deps/xineplug_xiph_la-xine_speex_decoder.Plo
> rm -f ./.deps/xineplug_xiph_la-xine_theora_decoder.Plo
> rm -f ./.deps/xineplug_xiph_la-xine_vorbis_decoder.Plo
> rm -f Makefile
> make[3]: Leaving directory '/<<PKGBUILDDIR>>/src/combined'
> Making distclean in vdr
> make[3]: Entering directory '/<<PKGBUILDDIR>>/src/vdr'
> rm -rf .libs _libs
> test -z "xineplug_vdr.la" || rm -f xineplug_vdr.la
> rm -f *.o
> rm -f *.lo
> rm -f *.tab.c
> test -z "" || rm -f 
> rm -f TAGS ID GTAGS GRTAGS GSYMS GPATH tags
> test . = "." || test -z "" || rm -f 
> rm -f ./so_locations
> rm -f ./.deps/xineplug_vdr_la-combined_vdr.Plo
> rm -f ./.deps/xineplug_vdr_la-input_vdr.Plo
> rm -f ./.deps/xineplug_vdr_la-post_vdr_audio.Plo
> rm -f ./.deps/xineplug_vdr_la-post_vdr_video.Plo
> rm -f Makefile
> make[3]: Leaving directory '/<<PKGBUILDDIR>>/src/vdr'
> make[3]: Entering directory '/<<PKGBUILDDIR>>/src'
> rm -rf .libs _libs
> rm -f *.lo
> test -z "" || rm -f 
> rm -f TAGS ID GTAGS GRTAGS GSYMS GPATH tags
> test . = "." || test -z "" || rm -f 
> make[3]: Leaving directory '/<<PKGBUILDDIR>>/src'
> rm -f Makefile
> make[2]: Leaving directory '/<<PKGBUILDDIR>>/src'
> Making distclean in contrib
> make[2]: Entering directory '/<<PKGBUILDDIR>>/contrib'
> Making distclean in a52dec
> make[3]: Entering directory '/<<PKGBUILDDIR>>/contrib/a52dec'
> rm -rf .libs _libs
> test -z "liba52.la" || rm -f liba52.la
> rm -f *.o
> rm -f *.lo
> rm -f *.tab.c
> test -z "" || rm -f 
> rm -f TAGS ID GTAGS GRTAGS GSYMS GPATH tags
> test . = "." || test -z "" || rm -f 
> rm -f ./so_locations
> rm -f ./.deps/liba52_la-bit_allocate.Plo
> rm -f ./.deps/liba52_la-bitstream.Plo
> rm -f ./.deps/liba52_la-crc.Plo
> rm -f ./.deps/liba52_la-downmix.Plo
> rm -f ./.deps/liba52_la-imdct.Plo
> rm -f ./.deps/liba52_la-parse.Plo
> rm -f Makefile
> make[3]: Leaving directory '/<<PKGBUILDDIR>>/contrib/a52dec'
> Making distclean in gsm610
> make[3]: Entering directory '/<<PKGBUILDDIR>>/contrib/gsm610'
> rm -rf .libs _libs
> test -z "libgsm610.la" || rm -f libgsm610.la
> rm -f *.o
> rm -f *.lo
> rm -f *.tab.c
> test -z "" || rm -f 
> rm -f TAGS ID GTAGS GRTAGS GSYMS GPATH tags
> test . = "." || test -z "" || rm -f 
> rm -f ./so_locations
> rm -f ./.deps/add.Plo
> rm -f ./.deps/decode.Plo
> rm -f ./.deps/gsm_create.Plo
> rm -f ./.deps/gsm_decode.Plo
> rm -f ./.deps/gsm_destroy.Plo
> rm -f ./.deps/long_term.Plo
> rm -f ./.deps/lpc.Plo
> rm -f ./.deps/rpe.Plo
> rm -f ./.deps/short_term.Plo
> rm -f ./.deps/table.Plo
> rm -f Makefile
> make[3]: Leaving directory '/<<PKGBUILDDIR>>/contrib/gsm610'
> Making distclean in libdca
> make[3]: Entering directory '/<<PKGBUILDDIR>>/contrib/libdca'
> rm -rf .libs _libs
> test -z "libdca.la" || rm -f libdca.la
> rm -f *.o
> rm -f *.lo
> rm -f *.tab.c
> test -z "" || rm -f 
> rm -f TAGS ID GTAGS GRTAGS GSYMS GPATH tags
> test . = "." || test -z "" || rm -f 
> rm -f ./so_locations
> rm -f ./.deps/libdca_la-bitstream.Plo
> rm -f ./.deps/libdca_la-downmix.Plo
> rm -f ./.deps/libdca_la-parse.Plo
> rm -f Makefile
> make[3]: Leaving directory '/<<PKGBUILDDIR>>/contrib/libdca'
> Making distclean in libfaad
> make[3]: Entering directory '/<<PKGBUILDDIR>>/contrib/libfaad'
> rm -rf .libs _libs
> test -z "" || rm -f 
> rm -f *.o
> rm -f *.lo
> rm -f *.tab.c
> test -z "" || rm -f 
> rm -f TAGS ID GTAGS GRTAGS GSYMS GPATH tags
> test . = "." || test -z "" || rm -f 
> rm -f ./.deps/libfaad_la-bits.Plo
> rm -f ./.deps/libfaad_la-cfft.Plo
> rm -f ./.deps/libfaad_la-common.Plo
> rm -f ./.deps/libfaad_la-decoder.Plo
> rm -f ./.deps/libfaad_la-drc.Plo
> rm -f ./.deps/libfaad_la-drm_dec.Plo
> rm -f ./.deps/libfaad_la-error.Plo
> rm -f ./.deps/libfaad_la-filtbank.Plo
> rm -f ./.deps/libfaad_la-hcr.Plo
> rm -f ./.deps/libfaad_la-huffman.Plo
> rm -f ./.deps/libfaad_la-ic_predict.Plo
> rm -f ./.deps/libfaad_la-is.Plo
> rm -f ./.deps/libfaad_la-lt_predict.Plo
> rm -f ./.deps/libfaad_la-mdct.Plo
> rm -f ./.deps/libfaad_la-mp4.Plo
> rm -f ./.deps/libfaad_la-ms.Plo
> rm -f ./.deps/libfaad_la-output.Plo
> rm -f ./.deps/libfaad_la-pns.Plo
> rm -f ./.deps/libfaad_la-ps_dec.Plo
> rm -f ./.deps/libfaad_la-ps_syntax.Plo
> rm -f ./.deps/libfaad_la-pulse.Plo
> rm -f ./.deps/libfaad_la-rvlc.Plo
> rm -f ./.deps/libfaad_la-sbr_dct.Plo
> rm -f ./.deps/libfaad_la-sbr_dec.Plo
> rm -f ./.deps/libfaad_la-sbr_e_nf.Plo
> rm -f ./.deps/libfaad_la-sbr_fbt.Plo
> rm -f ./.deps/libfaad_la-sbr_hfadj.Plo
> rm -f ./.deps/libfaad_la-sbr_hfgen.Plo
> rm -f ./.deps/libfaad_la-sbr_huff.Plo
> rm -f ./.deps/libfaad_la-sbr_qmf.Plo
> rm -f ./.deps/libfaad_la-sbr_syntax.Plo
> rm -f ./.deps/libfaad_la-sbr_tf_grid.Plo
> rm -f ./.deps/libfaad_la-specrec.Plo
> rm -f ./.deps/libfaad_la-ssr.Plo
> rm -f ./.deps/libfaad_la-ssr_fb.Plo
> rm -f ./.deps/libfaad_la-ssr_ipqf.Plo
> rm -f ./.deps/libfaad_la-syntax.Plo
> rm -f ./.deps/libfaad_la-tns.Plo
> rm -f Makefile
> make[3]: Leaving directory '/<<PKGBUILDDIR>>/contrib/libfaad'
> Making distclean in libmad
> make[3]: Entering directory '/<<PKGBUILDDIR>>/contrib/libmad'
> rm -rf .libs _libs
> test -z "" || rm -f 
> rm -f *.o
> rm -f *.lo
> rm -f *.tab.c
> test -z "" || rm -f 
> rm -f TAGS ID GTAGS GRTAGS GSYMS GPATH tags
> test . = "." || test -z "" || rm -f 
> rm -f ./.deps/bit.Plo
> rm -f ./.deps/decoder.Plo
> rm -f ./.deps/fixed.Plo
> rm -f ./.deps/frame.Plo
> rm -f ./.deps/huffman.Plo
> rm -f ./.deps/layer12.Plo
> rm -f ./.deps/layer3.Plo
> rm -f ./.deps/stream.Plo
> rm -f ./.deps/synth.Plo
> rm -f ./.deps/timer.Plo
> rm -f ./.deps/version.Plo
> rm -f Makefile
> make[3]: Leaving directory '/<<PKGBUILDDIR>>/contrib/libmad'
> Making distclean in libmpcdec
> make[3]: Entering directory '/<<PKGBUILDDIR>>/contrib/libmpcdec'
> rm -rf .libs _libs
> test -z "" || rm -f 
> rm -f *.o
> rm -f *.lo
> rm -f *.tab.c
> test -z "" || rm -f 
> rm -f TAGS ID GTAGS GRTAGS GSYMS GPATH tags
> test . = "." || test -z "" || rm -f 
> rm -f ./.deps/huffsv46.Plo
> rm -f ./.deps/huffsv7.Plo
> rm -f ./.deps/idtag.Plo
> rm -f ./.deps/mpc_decoder.Plo
> rm -f ./.deps/mpc_reader.Plo
> rm -f ./.deps/requant.Plo
> rm -f ./.deps/streaminfo.Plo
> rm -f ./.deps/synth_filter.Plo
> rm -f Makefile
> make[3]: Leaving directory '/<<PKGBUILDDIR>>/contrib/libmpcdec'
> Making distclean in libxdg-basedir
> make[3]: Entering directory '/<<PKGBUILDDIR>>/contrib/libxdg-basedir'
> rm -rf .libs _libs
> test -z "libxdg-basedir.la" || rm -f libxdg-basedir.la
> rm -f *.o
> rm -f *.lo
> rm -f *.tab.c
> test -z "" || rm -f 
> rm -f TAGS ID GTAGS GRTAGS GSYMS GPATH tags
> test . = "." || test -z "" || rm -f 
> rm -f ./so_locations
> rm -f ./.deps/basedir.Plo
> rm -f Makefile
> make[3]: Leaving directory '/<<PKGBUILDDIR>>/contrib/libxdg-basedir'
> Making distclean in nosefart
> make[3]: Entering directory '/<<PKGBUILDDIR>>/contrib/nosefart'
> rm -rf .libs _libs
> test -z "" || rm -f 
> rm -f *.o
> rm -f *.lo
> rm -f *.tab.c
> test -z "" || rm -f 
> rm -f TAGS ID GTAGS GRTAGS GSYMS GPATH tags
> test . = "." || test -z "" || rm -f 
> rm -f ./.deps/libnosefart_la-dis6502.Plo
> rm -f ./.deps/libnosefart_la-fds_snd.Plo
> rm -f ./.deps/libnosefart_la-fmopl.Plo
> rm -f ./.deps/libnosefart_la-log.Plo
> rm -f ./.deps/libnosefart_la-memguard.Plo
> rm -f ./.deps/libnosefart_la-mmc5_snd.Plo
> rm -f ./.deps/libnosefart_la-nes6502.Plo
> rm -f ./.deps/libnosefart_la-nes_apu.Plo
> rm -f ./.deps/libnosefart_la-nsf.Plo
> rm -f ./.deps/libnosefart_la-vrc7_snd.Plo
> rm -f ./.deps/libnosefart_la-vrcvisnd.Plo
> rm -f Makefile
> make[3]: Leaving directory '/<<PKGBUILDDIR>>/contrib/nosefart'
> Making distclean in libdha
> make[3]: Entering directory '/<<PKGBUILDDIR>>/contrib/libdha'
> Making distclean in bin
> make[4]: Entering directory '/<<PKGBUILDDIR>>/contrib/libdha/bin'
> rm -rf .libs _libs
> rm -f *.lo
> test -z "" || rm -f 
> test . = "." || test -z "" || rm -f 
> rm -f Makefile
> make[4]: Leaving directory '/<<PKGBUILDDIR>>/contrib/libdha/bin'
> Making distclean in oth
> make[4]: Entering directory '/<<PKGBUILDDIR>>/contrib/libdha/oth'
> rm -rf .libs _libs
> rm -f *.lo
> test -z "" || rm -f 
> test . = "." || test -z "" || rm -f 
> rm -f Makefile
> make[4]: Leaving directory '/<<PKGBUILDDIR>>/contrib/libdha/oth'
> Making distclean in sysdep
> make[4]: Entering directory '/<<PKGBUILDDIR>>/contrib/libdha/sysdep'
> rm -rf .libs _libs
> rm -f *.lo
> test -z "" || rm -f 
> rm -f TAGS ID GTAGS GRTAGS GSYMS GPATH tags
> test . = "." || test -z "" || rm -f 
> rm -f Makefile
> make[4]: Leaving directory '/<<PKGBUILDDIR>>/contrib/libdha/sysdep'
> Making distclean in kernelhelper
> make[4]: Entering directory '/<<PKGBUILDDIR>>/contrib/libdha/kernelhelper'
> rm -rf .libs _libs
> rm -f *.o
> rm -f *.lo
> rm -f *.tab.c
> test -z "" || rm -f 
> rm -f TAGS ID GTAGS GRTAGS GSYMS GPATH tags
> test . = "." || test -z "" || rm -f 
> rm -f ./.deps/test.Po
> rm -f Makefile
> make[4]: Leaving directory '/<<PKGBUILDDIR>>/contrib/libdha/kernelhelper'
> make[4]: Entering directory '/<<PKGBUILDDIR>>/contrib/libdha'
> test -z "pci_dev_ids.c pci_ids.h pci_names.c pci_names.h pci_vendors.h" || rm 
> -f pci_dev_ids.c pci_ids.h pci_names.c pci_names.h pci_vendors.h
> rm -rf .libs _libs
> test -z "" || rm -f 
> rm -f *.o
> rm -f *.lo
> rm -f *.tab.c
> test -z "" || rm -f 
> rm -f TAGS ID GTAGS GRTAGS GSYMS GPATH tags
> test . = "." || test -z "" || rm -f 
> make[4]: Leaving directory '/<<PKGBUILDDIR>>/contrib/libdha'
> rm -f ./.deps/cpu_flush.Plo
> rm -f ./.deps/irq.Plo
> rm -f ./.deps/libdha.Plo
> rm -f ./.deps/mmi.Plo
> rm -f ./.deps/mtrr.Plo
> rm -f ./.deps/pci.Plo
> rm -f ./.deps/pci_names.Plo
> rm -f ./.deps/ports.Plo
> rm -f ./.deps/test.Po
> rm -f Makefile
> make[3]: Leaving directory '/<<PKGBUILDDIR>>/contrib/libdha'
> Making distclean in vidix
> make[3]: Entering directory '/<<PKGBUILDDIR>>/contrib/vidix'
> Making distclean in drivers
> make[4]: Entering directory '/<<PKGBUILDDIR>>/contrib/vidix/drivers'
> rm -rf .libs _libs
> test -z "mach64_vid.la mga_crtc2_vid.la mga_vid.la pm2_vid.la pm3_vid.la 
> radeon_vid.la rage128_vid.la cyberblade_vid.la unichrome_vid.la nvidia_vid.la 
> sis_vid.la savage_vid.la " || rm -f mach64_vid.la mga_crtc2_vid.la mga_vid.la 
> pm2_vid.la pm3_vid.la radeon_vid.la rage128_vid.la cyberblade_vid.la 
> unichrome_vid.la nvidia_vid.la sis_vid.la savage_vid.la 
> rm -f *.o
> rm -f *.lo
> rm -f *.tab.c
> test -z "" || rm -f 
> rm -f TAGS ID GTAGS GRTAGS GSYMS GPATH tags
> test . = "." || test -z "" || rm -f 
> rm -f ./so_locations
> rm -f ./.deps/cyberblade_vid.Plo
> rm -f ./.deps/mach64_vid.Plo
> rm -f ./.deps/mga_crtc2_vid_la-mga_vid.Plo
> rm -f ./.deps/mga_vid.Plo
> rm -f ./.deps/nvidia_vid.Plo
> rm -f ./.deps/pm2_vid.Plo
> rm -f ./.deps/pm3_vid.Plo
> rm -f ./.deps/radeon_vid.Plo
> rm -f ./.deps/rage128_vid_la-radeon_vid.Plo
> rm -f ./.deps/savage_vid.Plo
> rm -f ./.deps/sis_bridge.Plo
> rm -f ./.deps/sis_vid.Plo
> rm -f ./.deps/unichrome_vid.Plo
> rm -f Makefile
> make[4]: Leaving directory '/<<PKGBUILDDIR>>/contrib/vidix/drivers'
> make[4]: Entering directory '/<<PKGBUILDDIR>>/contrib/vidix'
> rm -rf .libs _libs
> test -z "libvidix.la" || rm -f libvidix.la
> rm -f *.o
> rm -f *.lo
> rm -f *.tab.c
> test -z "" || rm -f 
> rm -f TAGS ID GTAGS GRTAGS GSYMS GPATH tags
> test . = "." || test -z "" || rm -f 
> rm -f ./so_locations
> make[4]: Leaving directory '/<<PKGBUILDDIR>>/contrib/vidix'
> rm -f ./.deps/vidixlib.Plo
> rm -f Makefile
> make[3]: Leaving directory '/<<PKGBUILDDIR>>/contrib/vidix'
> make[3]: Entering directory '/<<PKGBUILDDIR>>/contrib'
> rm -rf .libs _libs
> rm -f *.lo
> test -z "" || rm -f 
> rm -f TAGS ID GTAGS GRTAGS GSYMS GPATH tags
> test . = "." || test -z "" || rm -f 
> make[3]: Leaving directory '/<<PKGBUILDDIR>>/contrib'
> rm -f Makefile
> make[2]: Leaving directory '/<<PKGBUILDDIR>>/contrib'
> Making distclean in misc
> make[2]: Entering directory '/<<PKGBUILDDIR>>/misc'
> rm -rf .libs _libs
> rm -f *.o
> rm -f *.lo
> rm -f *.tab.c
> test -z "Makefile.plugins SlackBuild build_rpms.sh libxine.pc relchk.sh 
> xine-config xine-lib.spec" || rm -f Makefile.plugins SlackBuild build_rpms.sh 
> libxine.pc relchk.sh xine-config xine-lib.spec
>  rm -f xine-list-1.2
> rm -f TAGS ID GTAGS GRTAGS GSYMS GPATH tags
> test . = "." || test -z "" || rm -f 
> rm -f ./.deps/cdda_server.Po
> rm -f ./.deps/xine-list.Po
> rm -f ./.deps/xine_fontconv-xine-fontconv.Po
> rm -f Makefile
> make[2]: Leaving directory '/<<PKGBUILDDIR>>/misc'
> make[2]: Entering directory '/<<PKGBUILDDIR>>'
> test -z "a.out" || rm -f a.out
> rm -rf .libs _libs
> test -z "xine-lib_1.2.13-hg.tar.gz xine-lib_1.2.13-hg.tar.bz2 
> xine-lib-1.2.13-hg.tar.xz xine-lib-1.2.13-hg.tar.gz xine-lib.tgz 
> package_descriptions" || rm -f xine-lib_1.2.13-hg.tar.gz 
> xine-lib_1.2.13-hg.tar.bz2 xine-lib-1.2.13-hg.tar.xz 
> xine-lib-1.2.13-hg.tar.gz xine-lib.tgz package_descriptions
> rm -f *.lo
> rm -rf xine-lib-1.2.13-hg
> test -z "libtool po/Makevars.extra " || rm -f libtool po/Makevars.extra 
> rm -f include/configure.h include/stamp-h1
> rm -f libtool config.lt
> rm -f TAGS ID GTAGS GRTAGS GSYMS GPATH tags
> test . = "." || test -z "" || rm -f 
> rm -f cscope.out cscope.in.out cscope.po.out cscope.files
> test -z "include/xine/version.h" || rm -f include/xine/version.h
> make[2]: Leaving directory '/<<PKGBUILDDIR>>'
> rm -f config.status config.cache config.log configure.lineno 
> config.status.lineno
> rm -f Makefile
> make[1]: Leaving directory '/<<PKGBUILDDIR>>'
>    dh_autoreconf_clean
>    dh_clean
>  dpkg-source -b .
> dpkg-source: info: using source format '3.0 (quilt)'
> dpkg-source: info: building xine-lib-1.2 using existing 
> ./xine-lib-1.2_1.2.13+hg20230710.orig.tar.gz
> dpkg-source: error: cannot represent change to po/cs.gmo: binary file 
> contents changed
> dpkg-source: error: add po/cs.gmo in debian/source/include-binaries if you 
> want to store the modified binary in the debian tarball
> dpkg-source: error: cannot represent change to po/de.gmo: binary file 
> contents changed
> dpkg-source: error: add po/de.gmo in debian/source/include-binaries if you 
> want to store the modified binary in the debian tarball
> dpkg-source: error: cannot represent change to po/en_US.gmo: binary file 
> contents changed
> dpkg-source: error: add po/en_US.gmo in debian/source/include-binaries if you 
> want to store the modified binary in the debian tarball
> dpkg-source: error: cannot represent change to po/eo.gmo: binary file 
> contents changed
> dpkg-source: error: add po/eo.gmo in debian/source/include-binaries if you 
> want to store the modified binary in the debian tarball
> dpkg-source: error: cannot represent change to po/es.gmo: binary file 
> contents changed
> dpkg-source: error: add po/es.gmo in debian/source/include-binaries if you 
> want to store the modified binary in the debian tarball
> dpkg-source: error: cannot represent change to po/eu.gmo: binary file 
> contents changed
> dpkg-source: error: add po/eu.gmo in debian/source/include-binaries if you 
> want to store the modified binary in the debian tarball
> dpkg-source: error: cannot represent change to po/fr.gmo: binary file 
> contents changed
> dpkg-source: error: add po/fr.gmo in debian/source/include-binaries if you 
> want to store the modified binary in the debian tarball
> dpkg-source: error: cannot represent change to po/it.gmo: binary file 
> contents changed
> dpkg-source: error: add po/it.gmo in debian/source/include-binaries if you 
> want to store the modified binary in the debian tarball
> dpkg-source: error: cannot represent change to po/ja.gmo: binary file 
> contents changed
> dpkg-source: error: add po/ja.gmo in debian/source/include-binaries if you 
> want to store the modified binary in the debian tarball
> dpkg-source: error: cannot represent change to po/nl.gmo: binary file 
> contents changed
> dpkg-source: error: add po/nl.gmo in debian/source/include-binaries if you 
> want to store the modified binary in the debian tarball
> dpkg-source: error: cannot represent change to po/pl.gmo: binary file 
> contents changed
> dpkg-source: error: add po/pl.gmo in debian/source/include-binaries if you 
> want to store the modified binary in the debian tarball
> dpkg-source: error: cannot represent change to po/pt_BR.gmo: binary file 
> contents changed
> dpkg-source: error: add po/pt_BR.gmo in debian/source/include-binaries if you 
> want to store the modified binary in the debian tarball
> dpkg-source: error: cannot represent change to po/sk.gmo: binary file 
> contents changed
> dpkg-source: error: add po/sk.gmo in debian/source/include-binaries if you 
> want to store the modified binary in the debian tarball
> dpkg-source: error: cannot represent change to po/tr.gmo: binary file 
> contents changed
> dpkg-source: error: add po/tr.gmo in debian/source/include-binaries if you 
> want to store the modified binary in the debian tarball
> dpkg-source: error: unrepresentable changes to source
> dpkg-buildpackage: error: dpkg-source -b . subprocess returned exit status 1
> 
> E: Command 'cd /<<PKGBUILDDIR>> && runuser -u user42 -- dpkg-buildpackage 
> --sanitize-env -us -uc -rfakeroot -S' failed to run.


The full build log is available from:
http://qa-logs.debian.net/2023/08/13/xine-lib-1.2_1.2.13+hg20230710-1_unstable.log

If you reassign this bug to another package, please mark it as 'affects'-ing
this package. See https://www.debian.org/Bugs/server-control#affects

If you fail to reproduce this, please provide a build log and diff it with mine
so that we can identify if something relevant changed in the meantime.

Reply via email to